<?php
/**
 * This displays an header on all of the site pages.
 *
 * @package H-Display
 * @version 1.1
 */

/*
Plugin Name: H-Display
Plugin URI: https://www.zaqlabs.com
Description: A simple plugin for adding a notification bar to your website.
Version: 1.1
Author: Lawani Abdulrasaq
Author URI: https://www.zaqlabs.com
License: GPLv2 or later
Text Domain: h-display
*/


if ( ! defined( 'H_DISPLAY_DIR' ) ) {
		define( 'H_DISPLAY_DIR', __FILE__ );
}

/**
 * Outputs the header to be displayed on all pages.
 *
 * @author  Abdulrasaq Lawani <info@zaqlabs.com>
 *
 * @since 1.1
 *
 * @return void
 */
function h_display_show_header() {
	echo "<div class='h-display-header-style'>" . esc_html( get_option( 'h_message' ) ) . '</div>';
}

/**
 * Addition of Style for the notification.
 *
 * @author  Abdulrasaq Lawani <info@zaqlabs.com>
 *
 * @since 1.1
 *
 * @return void
 */
function h_display_add_style() {

		/**
		*  Defaults
		*$text_alignment ="center";
		*$color = "black";
		*$bg_color ="red";
		*$font_size = "28";
		*$padding = "20";
		*/

		$text_alignment = get_option( 'txt_align' );
		$color          = get_option( 'color' );
		$bg_color       = get_option( 'bg_color' );
		$font_size      = get_option( 'font_size' );
		$padding        = get_option( 'padding' );

		echo(
		'<style>

                div.h-display-header-style {
                                color:' . esc_html( $color ) . ';
                                background-color:' . esc_html( $bg_color ) . ';
                                padding: ' . esc_html( $padding ) . 'px;
                                display: flex;
                                align-items:center;
                                justify-content:' . esc_html( $text_alignment ) . ';
                                font-size:' . esc_html( $font_size ) . 'px;
                                margin:0px; 
                                line-height: normal;
                        }
                html {
                        }

                </style>'
		);
}

/**
 * Menu Creation.
 *
 *  @author  Abdulrasaq Lawani <info@zaqlabs.com>
 *
 * @since 1.1
 *
 * @return void
 */
add_action( 'admin_menu', 'h_display_plugin_menu' );

/**
 * Function to create an admin menu.
 *
 *  @author  Abdulrasaq Lawani <info@zaqlabs.com>
 *
 * @since 1.1
 *
 * @return void
 */
function h_display_plugin_menu() {
		$page_title = 'H Display Page';
		$menu_title = 'H-Display';
		$capability = 'manage_options';
		$menu_slug  = 'h-plugin';
		$function   = 'h_display_initialize';
		$icon_url   = 'dashicons-megaphone';
		$position   = 5;

		add_menu_page( $page_title, $menu_title, $capability, $menu_slug, $function, $icon_url, $position );

		add_action( 'admin_init', 'h_update_display_info' );
}

/**
 * Admin HTML.
 *
 * @author  Abdulrasaq Lawani <info@zaqlabs.com>
 *
 * @since 1.1
 *
 * @return void
 */
function h_display_initialize() {
	?>
		<div id="h-display-app">
				<h1>Edit your Notification</h1>
				<div id='h_display_preview'><?php echo esc_html( get_option( 'h_message' ) ); ?></div>
						<form method="post" action="options.php" >
										<?php settings_fields( 'h_display_settings' ); ?>
										<?php do_settings_sections( 'h_display_settings' ); ?>
				<table class="h-form-table">
						<tr valign="top">
						<th scope="row">Your Message:</th>
						<td><input type="text" id="h_display_message" name="h_message" value="<?php echo esc_html( get_option( 'h_message' ) ); ?>" style="width:100%"/></td>
						</tr>
						<tr valign="top">
						<th scope="row">Text Color:</th>
						<td><input type="color" id="h_display_color" name="color" value="<?php echo esc_html( get_option( 'color' ) ); ?>"/></td>
						</tr>
						<tr valign="top">
						<th scope="row">Background Color:</th>
						<td><input type="color" id="h_display_bg_color" name="bg_color" value="<?php echo esc_html( get_option( 'bg_color' ) ); ?>"/></td>
						</tr>
						<tr valign="top">
						<th scope="row">Padding (in px):</th>
						<td><input type="number" id="h_display_padding" name="padding" value="<?php echo esc_html( get_option( 'padding' ) ); ?>"/></td>
						</tr>
						<tr valign="top">
						<th scope="row">Text Alignment:</th>
						<td>
						<select id="h_display_txt_align" name="txt_align">
								<option value="flex-start" 
								<?php
								if ( get_option( 'txt_align' ) === 'flex-start' ) {
										echo 'selected';}
								?>
								>Left</option>
								<option value="center" 
								<?php
								if ( get_option( 'txt_align' ) === 'center' ) {
										echo 'selected';}
								?>
								>Center</option>
								<option value="flex-end" 
								<?php
								if ( get_option( 'txt_align' ) === 'flex-end' ) {
										echo 'selected';}
								?>
								>Right</option>
						</select>
						</tr>
						<tr valign="top">
						<th scope="row">Font Size (in px):</th>
						<td><input type="number" id="h_display_font_size" name="font_size" value="<?php echo esc_html( get_option( 'font_size' ) ); ?>"/></td>
						</tr>
				</table>
				<?php submit_button(); ?>
				</form>
		</div>
		
		<script>
				function updateHDisplayPreview(event, value){

						const element = event.srcElement; 
						let h_display_preview = document.querySelector('#h_display_preview');

						if (element.id === 'h_display_message')
								h_display_preview.innerText = element.value;

						if (element.id === 'h_display_color')
								h_display_preview.style.color = element.value;

						if (element.id === 'h_display_bg_color')
								h_display_preview.style.backgroundColor = element.value;
						
						if (element.id === 'h_display_padding')
								h_display_preview.style.padding = element.value +'px';
						
						if (element.id === 'h_display_txt_align')
								h_display_preview.style.justifyContent = element.value;

						if (element.id === 'h_display_font_size')
								h_display_preview.style.fontSize = element.value +'px';

				}
				window.onload = function afterWebPageLoad() {
						let h_display_message = document.querySelector('#h_display_message');
						let h_display_color = document.querySelector('#h_display_color');
						let h_display_bg_color = document.querySelector('#h_display_bg_color');
						let h_display_padding = document.querySelector('#h_display_padding');
						let h_display_txt_align = document.querySelector('#h_display_txt_align');
						let h_display_font_size = document.querySelector('#h_display_font_size');

						let h_display_preview = document.querySelector('#h_display_preview');

						h_display_preview.style.innerText = h_display_message.value;
						h_display_preview.style.color = h_display_color.value;
						h_display_preview.style.backgroundColor = h_display_bg_color.value;
						h_display_preview.style.padding = h_display_padding.value +'px';
						h_display_preview.style.justifyContent = h_display_txt_align.value;
						h_display_preview.style.fontSize = h_display_font_size.value +'px';

						h_display_message.addEventListener('keyup', updateHDisplayPreview);
						h_display_color.addEventListener('change', updateHDisplayPreview);
						h_display_bg_color.addEventListener('change', updateHDisplayPreview);
						h_display_padding.addEventListener('change', updateHDisplayPreview);
						h_display_txt_align.addEventListener('change', updateHDisplayPreview);
						h_display_font_size.addEventListener('change', updateHDisplayPreview);

				}

		</script>
		<style>
		div#h-display-app {
				padding-right: 3%;
				}

		div#h_display_preview{
				margin-bottom: 10px;
				display: flex;
				align-items: center;
				line-height: normal;
		}
		</style>
	<?php
}

/**
 * Adds the javascipt to move the header to the right position.
 *
 * @author  Abdulrasaq Lawani <info@zaqlabs.com>
 *
 * @since 1.1
 *
 * @return void
 */
function move_display_to_top() {
		wp_enqueue_script( 'jquery' );
	?>
		<script type="text/javascript">

				window.onload = function afterWebPageLoad() {
						jQuery('body').prepend(jQuery('div.h-display-header-style'));
				}

		</script>
		<?php
}

/**
 *  Additions of all admin settings.
 *
 * @author  Abdulrasaq Lawani <info@zaqlabs.com>
 *
 * @since 1.1
 *
 * @return void
 */
function h_update_display_info() {
	register_setting( 'h_display_settings', 'h_message' );
		register_setting( 'h_display_settings', 'color' );
		register_setting( 'h_display_settings', 'bg_color' );
		register_setting( 'h_display_settings', 'padding' );
		register_setting( 'h_display_settings', 'txt_align' );
		register_setting( 'h_display_settings', 'font_size' );
}



/**
 *  Additions of options if non-existent.
 *
 * @author  Abdulrasaq Lawani <info@zaqlabs.com>
 *
 * @since 1.1
 *
 * @return void
 */
function h_display_options() {
	if ( ! get_option( 'txt_align' ) ) {
			update_option( 'txt_align', 'center' );
	}
	if ( ! get_option( 'color' ) ) {
			update_option( 'color', 'black' );
	}
	if ( ! get_option( 'bg_color' ) ) {
			update_option( 'bg_color', 'red' );
	}
	if ( ! get_option( 'font_size' ) ) {
			update_option( 'font_size', '28' );
	}
	if ( ! get_option( 'padding' ) ) {
			update_option( 'padding', '28' );
	}
}

/**
 *  Additions of settings url.
 *
 * @author  Abdulrasaq Lawani <info@zaqlabs.com>
 *
 * @param array $links  This is an array of links for the menu items and its sub-items.
 *
 * @since 1.1
 *
 * @return array
 */
function hdisplay_add_plugin_page_settings_link( $links ) {
	$links[] = '<a href="' .
		admin_url( 'options-general.php?page=h-plugin' ) .
		'">' . __( 'Settings' ) . '</a>';
	return $links;
}

/**
 * Action and filter Functions.
 *      0. addition of scripts to modify the position of the header.
 *      1. additions of message.
 *      2. additions of style.
 *      3. addtions of settings.
 *      4. register.
 *
 * @author  Abdulrasaq Lawani <info@zaqlabs.com>
 *
 * @since 1.1
 *
 * @return void
 */
add_action( 'wp_footer', 'move_display_to_top', 2 );
add_action( 'wp_footer', 'h_display_show_header', 2 );
add_action( 'wp_head', 'h_display_add_style' );
add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'hdisplay_add_plugin_page_settings_link' );
register_activation_hook( __FILE__, 'h_display_options' );
?>
